@@ -5,7 +5,7 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  * 
- * Copyright (C) 2010-2014 Matthew Turnbull <sparky@bluefang-logic.com>. All Rights Reserved.
+ * Copyright (C) 2010-2015 Matthew Turnbull <sparky@bluefang-logic.com>. All Rights Reserved.
  * 
  * ***** END LICENSE BLOCK *****
 */
@@ -20,12 +20,6 @@ const CU = Components.utils;
 CU.import("resource://gre/modules/XPCOMUtils.jsm");
 CU.import("resource://gre/modules/Services.jsm");
 
-let AustralisTools = null;
-if(Services.vc.compare("28.*", Services.appinfo.version) < 0)
-{
-	AustralisTools = CU.import("resource://status4evar/Australis.jsm", {}).AustralisTools;
-}
-
 const CURRENT_MIGRATION = 7;
 
 function Status_4_Evar(){}
@@ -42,7 +36,6 @@ Status_4_Evar.prototype =
 	prefs:          null,
 
 	addonbarBorderStyle:            false,
-	addonbarCloseButton:            false,
 	addonbarLegacyShim:             true,
 	addonbarWindowGripper:          true,
 
@@ -108,31 +101,13 @@ Status_4_Evar.prototype =
 			}
 		},
 
-		"addonbar.closeButton":
-		{
-			update: function()
-			{
-				this.addonbarCloseButton = this.prefs.getBoolPref("addonbar.closeButton");
-			},
-			updateWindow: function(win)
-			{
-				let addonbar_close_button = win.caligon.status4evar.getters.addonbarCloseButton;
-				if(addonbar_close_button)
-				{
-					addonbar_close_button.hidden = !this.addonbarCloseButton;
-				} 
-			}
-		},
-
 		"addonbar.legacyShim":
 		{
 			update: function()
 			{
 				this.addonbarLegacyShim = this.prefs.getBoolPref("addonbar.legacyShim");
-				if(AustralisTools)
-				{
-					AustralisTools.updateLegacyShim(this.addonbarLegacyShim);
-				}
+
+				CU.import("resource://status4evar/Australis.jsm", {}).AustralisTools.updateLegacyShim(this.addonbarLegacyShim);
 			}
 		},
 
@@ -237,9 +212,6 @@ Status_4_Evar.prototype =
 				{
 					this.setBoolElementAttribute(download_button, "forcevisible", this.downloadForce);
 				}
-
-				let download_notify_anchor = win.caligon.status4evar.getters.downloadNotifyAnchor;
-				this.setBoolElementAttribute(download_notify_anchor, "forcevisible", this.downloadForce);
 			}
 		},
 
@@ -645,7 +617,9 @@ Status_4_Evar.prototype =
 
 	startup: function()
 	{
-		this.prefs = Services.prefs.getBranch("status4evar.").QueryInterface(CI.nsIPrefBranch2);
+		this.prefs = Services.prefs.getBranch("extensions.caligon.s4e.").QueryInterface(CI.nsIPrefBranch2);
+
+		this.migratePrefsRoot();
 
 		this.firstRun = this.prefs.getBoolPref("firstRun");
 		if(this.firstRun)
@@ -695,6 +669,33 @@ Status_4_Evar.prototype =
 		this.prefs = null;
 	},
 
+	migratePrefsRoot: function()
+	{
+		let oldPrefs = Services.prefs.getBranch("status4evar.").QueryInterface(CI.nsIPrefBranch2);
+
+		let childPrefs = oldPrefs.getChildList("");
+		childPrefs.forEach(function(pref)
+		{
+			if(oldPrefs.prefHasUserValue(pref))
+			{
+				switch(oldPrefs.getPrefType(pref))
+				{
+					case CI.nsIPrefBranch2.PREF_STRING:
+						this.prefs.setCharPref(pref, oldPrefs.getCharPref(pref));
+						break;
+					case CI.nsIPrefBranch2.PREF_INT:
+						this.prefs.setIntPref(pref, oldPrefs.getIntPref(pref));
+						break;
+					case CI.nsIPrefBranch2.PREF_BOOL:
+						this.prefs.setBoolPref(pref, oldPrefs.getBoolPref(pref));
+						break;
+				}
+
+				oldPrefs.clearUserPref(pref);
+			}
+		}, this);
+	},
+
 	migrate: function()
 	{
 		if(!this.firstRun)
